<h1 align="center"><a href="https://nshimizu0721.github.io/molass-library"><img src="docs/_static/molass-title.png" width="300"></a></h1>

> [!WARNING]
> The initial version of this package is currently in preparation to be available in July, 2025.

Molass Library is a rewrite of [MOLASS](https://www.jstage.jst.go.jp/article/biophysico/20/1/20_e200001/_article), an analytical tool for SEC-SAXS experiment data currently hosted at [Photon Factory](https://pfwww.kek.jp/saxs/MOLASS.html), Japan.

To install this package, use pip as follows.

```
pip install -U molass
```

> [!NOTE]
> The molass package currently depends on molass_legacy. This dependency is planned to be removed.

For details, see also:

- **Essence:** https://nshimizu0721.github.io/molass-essence for theory,
- **Tutorial:** https://nshimizu0721.github.io/molass-tutorial for how to use,
- **Technical:** https://nshimizu0721.github.io/molass-technical for technical details,
- **Reference:** https://nshimizu0721.github.io/molass-library for function reference,
- **Legacy Repository:** https://github.com/freesemt/molass-legacy for legacy codes.

To join the community, see also:

- **Handbook:** https://nshimizu0721.github.io/molass-develop for maintenance.

<br>